@@ -85,4 +85,15 @@ public({
         expect_identical(length(cacheKeys()), 0L)
         expect_identical(a$response, 35L)
     })
+
+    test_that("Requests with an invalid URL return a useful error", {
+        expect_error(GET(NULL), "Invalid URL: NULL")
+        expect_error(GET(table(1:5)),
+            "Invalid URL: structure(c(1L, 1L, 1L, 1L, 1L), .Dim = 5L, .Dimnames = structure(list(",
+            fixed=TRUE)
+        setClass("TestS4Obj", contains="environment")
+        expect_error(GET(new("TestS4Obj")),
+            'Invalid URL: <S4 object of class structure("TestS4Obj", package = ".GlobalEnv")>',
+            fixed=TRUE)
+    })
 })
